==> haskell-libxml-sax-0.7.5-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-libxml-sax.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: libxml-sax
version: 0.7.5
id: libxml-sax-0.7.5-CZNJ7yMYetWDObZtx2BxlB
key: libxml-sax-0.7.5-CZNJ7yMYetWDObZtx2BxlB
license: MIT
maintainer: jmillikin@gmail.com
stability: experimental
homepage: https://john-millikin.com/software/haskell-libxml/
synopsis: Bindings for the libXML2 SAX interface
category: Foreign, Text, XML, Parsing
author: John Millikin
exposed: True
indefinite: False
exposed-modules:
    Text.XML.LibXML.SAX
abi: 68088c31c378626ce9ceb6931c5387fd
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/libxml-sax-0.7.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/libxml-sax-0.7.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/libxml-sax-0.7.5
hs-libraries: HSlibxml-sax-0.7.5-CZNJ7yMYetWDObZtx2BxlB
extra-libraries:
    xml2 xml2
include-dirs: /usr/include/libxml2
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    xml-types-0.3.6-8U94ZZax169GYLVDpT1mig
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             xml-types-0.3.6-8U94ZZax169GYLVDpT1mig=d5c752ba65b163e7bdddd7a60950098d
haddock-interfaces: /usr/share/doc/haskell-libxml-sax/html/libxml-sax.haddock
haddock-html: /usr/share/doc/haskell-libxml-sax/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libxml-sax-0.7.5-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-libxml-sax.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: libxml-sax
version: 0.7.5
id: libxml-sax-0.7.5-9uJRjofyhKXDY1KBQQfeQn
key: libxml-sax-0.7.5-9uJRjofyhKXDY1KBQQfeQn
license: MIT
maintainer: jmillikin@gmail.com
stability: experimental
homepage: https://john-millikin.com/software/haskell-libxml/
synopsis: Bindings for the libXML2 SAX interface
category: Foreign, Text, XML, Parsing
author: John Millikin
exposed: True
indefinite: False
exposed-modules:
    Text.XML.LibXML.SAX
abi: ae476ce38361b2a40eddc0731cf8b464
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/libxml-sax-0.7.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/libxml-sax-0.7.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/libxml-sax-0.7.5
hs-libraries: HSlibxml-sax-0.7.5-9uJRjofyhKXDY1KBQQfeQn
extra-libraries:
    xml2 xml2
include-dirs: /usr/include/libxml2
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    xml-types-0.3.6-GzQgX9Brh0VH8ue9BSAlZr
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             xml-types-0.3.6-GzQgX9Brh0VH8ue9BSAlZr=edf071c0face4ef12f6ee1822aae3316
haddock-interfaces: /usr/share/doc/haskell-libxml-sax/html/libxml-sax.haddock
haddock-html: /usr/share/doc/haskell-libxml-sax/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
